@@ -47,7 +47,6 @@
 #include "gedit-commands.h"
 #include "gedit-preferences-dialog.h"
 #include "gedit-tab.h"
-#include "gedit-tab-private.h"
 
 #define GEDIT_PAGE_SETUP_FILE		"gedit-page-setup"
 #define GEDIT_PRINT_SETTINGS_FILE	"gedit-print-settings"
@@ -73,7 +72,6 @@ typedef struct
 	GMenuModel        *line_col_menu;
 
 	PeasExtensionSet  *extensions;
-	GNetworkMonitor   *monitor;
 
 	/* command line parsing */
 	gboolean new_window;
@@ -1382,55 +1380,12 @@ load_print_settings (GeditApp *app)
 	}
 }
 
-static void
-get_network_available (GNetworkMonitor *monitor,
-		       gboolean         available,
-		       GeditApp        *app)
-{
-	gboolean enable;
-	GList *windows, *w;
-
-	enable = g_network_monitor_get_network_available (monitor);
-
-	windows = gtk_application_get_windows (GTK_APPLICATION (app));
-
-	for (w = windows; w != NULL; w = w->next)
-	{
-		GeditWindow *window = GEDIT_WINDOW (w->data);
-
-		if (GEDIT_IS_WINDOW (window))
-		{
-			GList *tabs, *t;
-
-			tabs = _gedit_window_get_all_tabs (window);
-
-			for (t = tabs; t != NULL; t = t->next)
-			{
-				_gedit_tab_set_network_available (GEDIT_TAB (t->data),
-					                          enable);
-			}
-
-			g_list_free (tabs);
-		}
-	}
-}
-
 static void
 gedit_app_init (GeditApp *app)
 {
-	GeditAppPrivate *priv;
-
-	priv = gedit_app_get_instance_private (app);
-
 	g_set_application_name ("gedit");
 	gtk_window_set_default_icon_name ("gedit");
 
-	priv->monitor = g_network_monitor_get_default ();
-	g_signal_connect (priv->monitor,
-	                  "network-changed",
-	                  G_CALLBACK (get_network_available),
-	                  app);
-
 	g_application_add_main_option_entries (G_APPLICATION (app), options);
 
 #ifdef ENABLE_INTROSPECTION
