@@ -441,14 +441,10 @@ _gedit_cmd_file_open (GSimpleAction *action,
 		{
 			g_return_if_fail (GEDIT_IS_FILE_CHOOSER_DIALOG (data));
 
-			gedit_file_chooser_dialog_show (GEDIT_FILE_CHOOSER_DIALOG (data));
+			gtk_window_present (GTK_WINDOW (data));
 
 			return;
 		}
-
-		/* FIXME: this should be in GeditWindow. */
-		gtk_widget_hide (GTK_WIDGET (window->priv->open_document_popover));
-		gtk_widget_hide (GTK_WIDGET (window->priv->fullscreen_open_document_popover));
 	}
 
 	/* Translators: "Open" is the title of the file chooser window. */
@@ -1078,28 +1074,13 @@ _gedit_cmd_file_save (GSimpleAction *action,
 {
 	GeditWindow *window = GEDIT_WINDOW (user_data);
 	GeditTab *tab;
-	GeditDocument *doc;
 
 	gedit_debug (DEBUG_COMMANDS);
 
 	tab = gedit_window_get_active_tab (window);
 	if (tab != NULL)
 	{
-		doc = gedit_tab_get_document (tab);
-		g_return_if_fail (doc != NULL);
-
-		if (_gedit_document_needs_saving (doc) ||
-		    gedit_document_is_untitled (doc))
-		{
-			save_tab (tab, window);
-		}
-		else
-		{
-			gedit_statusbar_flash_message (GEDIT_STATUSBAR (window->priv->statusbar),
-						       window->priv->generic_message_cid,
-						       _("No changes need to be saved"));
-
-		}
+		save_tab (tab, window);
 	}
 }
 
