@@ -22,8 +22,8 @@
  * Boston, MA  02110-1301  USA
  */
 
-#ifndef __GEDIT_FILE_BROWSER_MESSAGE_SET_MARKUP_H__
-#define __GEDIT_FILE_BROWSER_MESSAGE_SET_MARKUP_H__
+#ifndef GEDIT_FILE_BROWSER_MESSAGE_SET_MARKUP_H
+#define GEDIT_FILE_BROWSER_MESSAGE_SET_MARKUP_H
 
 #include <gedit/gedit-message.h>
 
@@ -67,4 +67,4 @@ GType gedit_file_browser_message_set_markup_get_type (void) G_GNUC_CONST;
 
 G_END_DECLS
 
-#endif /* __GEDIT_FILE_BROWSER_MESSAGE_SET_MARKUP_H__ */
+#endif /* GEDIT_FILE_BROWSER_MESSAGE_SET_MARKUP_H */
