@@ -28,6 +28,14 @@ from .signals import Signals
 from .shareddata import SharedData
 from . import helper
 
+try:
+    import gettext
+    gettext.bindtextdomain('gedit')
+    gettext.textdomain('gedit')
+    _ = gettext.gettext
+except:
+    _ = lambda s: s
+
 class DynamicSnippet(dict):
     def __init__(self, text):
         self['text'] = text
@@ -37,7 +45,7 @@ class Document(GObject.Object, Gedit.ViewActivatable, Signals):
     TAB_KEY_VAL = (Gdk.KEY_Tab, Gdk.KEY_ISO_Left_Tab)
     SPACE_KEY_VAL = (Gdk.KEY_space,)
 
-    view = GObject.property(type=Gedit.View)
+    view = GObject.Property(type=Gedit.View)
 
     def __init__(self):
         GObject.Object.__init__(self)
@@ -430,7 +438,7 @@ class Document(GObject.Object, Gedit.ViewActivatable, Signals):
 
         if isinstance(toplevel, Gedit.Window):
             for doc in toplevel.get_documents():
-                r = self.location_uri_for_env(doc.get_location())
+                r = self.location_uri_for_env(doc.get_file().get_location())
 
                 if isinstance(r, dict):
                     documents_uri['utf8'].append(r['utf8'])
@@ -449,7 +457,7 @@ class Document(GObject.Object, Gedit.ViewActivatable, Signals):
 
         if isinstance(toplevel, Gedit.Window):
             for doc in toplevel.get_documents():
-                r = self.location_path_for_env(doc.get_location())
+                r = self.location_path_for_env(doc.get_file().get_location())
 
                 if isinstance(r, dict):
                     documents_path['utf8'].append(r['utf8'])
@@ -489,7 +497,7 @@ class Document(GObject.Object, Gedit.ViewActivatable, Signals):
                 environ['utf8'][var] = v
                 environ['noenc'][var] = str(v)
 
-        self.env_add_for_location(environ, buf.get_location(), 'GEDIT_CURRENT_DOCUMENT')
+        self.env_add_for_location(environ, buf.get_file().get_location(), 'GEDIT_CURRENT_DOCUMENT')
 
         return environ
 
@@ -873,7 +881,7 @@ class Document(GObject.Object, Gedit.ViewActivatable, Signals):
         self.env_add_for_location(environ, gfile, 'GEDIT_DROP_DOCUMENT')
 
         buf = self.view.get_buffer()
-        location = buf.get_location()
+        location = buf.get_file().get_location()
 
         relpath = location.get_relative_path(gfile)
 
